@@ -25,6 +25,9 @@ def _process_pandas_object(pandas_object: Union[pd.Series, pd.DataFrame]) -> Tup
 
     Returns:
         tuple of (sample period, start time, end time)
+
+    Raises:
+        ValueError: if index does not have a frequency or if the pandas object is empty
     """
     # Validate pandas object fulfills `TimeArray` requirements.
     if pandas_object.index.freq is None:
@@ -89,10 +92,16 @@ def _get_axis_labels_to_collapse(indexer: ItemOrSlice, axis_labels: AxisLabels)
     )
 
 
+def ndarray_to_list(a: np.ndarray) -> list:
+    """Converts a numpy array to a json-serializable list."""
+    return np.where(np.isnan(a), None, a).tolist() if a is not None else None
+
+
 class TimeArray(BaseModel):
     class Config:
         # Allow arbitrary types in order to support `np.ndarray` directly.
         arbitrary_types_allowed = True
+        json_encoders = {np.ndarray: ndarray_to_list}
 
     sample_period: TimeDelta
     start_time: Time
@@ -369,6 +378,9 @@ class TimeArray(BaseModel):
 
         Returns:
             time array
+
+        Raises:
+            ValueError: if data frame does not represent a valid time array
         """
         sample_period, start_time, end_time = _process_pandas_object(pandas_object=pandas_data_frame)
 
@@ -460,6 +472,9 @@ class TimeArray(BaseModel):
 
         Returns:
             time array
+
+        Raises:
+            ValueError: if object is neither a `pandas.Series` or `pandas.DataFrame`
         """
         if isinstance(pandas_object, pd.Series):
             time_array = cls.from_pandas_series(pandas_series=pandas_object, as_of_time=as_of_time, mask=mask)
@@ -559,15 +574,3 @@ class TimeArray(BaseModel):
             return self.to_pandas_series(apply_mask=apply_mask)
         else:
             return self.to_pandas_data_frame(apply_mask=apply_mask)
-
-    def dict(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
-        """Returns the dictionary representation of this `TimeArray`."""
-        dict_repr = super().dict(*args, **kwargs)
-
-        arr: np.ndarray = dict_repr["values"]
-        dict_repr["values"] = np.where(np.isnan(arr), None, arr).tolist()
-
-        if self.mask is not None:
-            dict_repr["mask"] = dict_repr["mask"].tolist()
-
-        return dict_repr
