@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.time_series_get import TimeSeriesGet
+from myst.openapi.models.time_series_get import TimeSeriesGet
 
 
 class TimeSeriesList(base_model.BaseModel):
